Application configuration - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# Application configuration

Betty uses global application configuration for settings that do not impact your projects, such as the language you want to use Betty in, e.g. for the user interface and logs. This configuration can be managed through the `betty config` command.